@@ -10,20 +10,18 @@ __all__ = [
     "Callback"
 ]
 
-_TYPES = lambda: {object}
-
 Data = ModelIO | object
 
 @dataclass
 class Callback:
 
-    types: Iterable[type[Data]] = field(default_factory=_TYPES)
+    types: Iterable[type[Data]] = field(default_factory=set)
     callback: Callable[[Data], Awaitable[...] | ...] = None
     preparation: Callable[[], Awaitable[...] | ...] = None
     enabled: bool = True
     prepared: bool = False
 
-    async def prepare(self) -> None:
+    async def async_prepare(self) -> None:
         """Connects to the socket service."""
 
         if self.preparation:
@@ -35,18 +33,41 @@ class Callback:
 
         self.prepared = True
 
-    async def execute(self, data: Data) -> None:
+    def prepare(self) -> None:
+        """Connects to the socket service."""
+
+        if self.preparation:
+            if asyncio.iscoroutinefunction(self.preparation):
+                asyncio.run(self.preparation())
+
+            else:
+                self.preparation()
+
+        self.prepared = True
+
+    async def async_execute(self, data: Data) -> None:
 
         if not isinstance(data, tuple(self.types)):
             return
 
         if self.enabled:
             if not self.prepared:
-                await self.prepare()
+                await self.async_prepare()
 
-            await self.call(data=data)
+            await self.async_call(data=data)
 
-    async def call(self, data: Data) -> None:
+    def execute(self, data: Data) -> None:
+
+        if not isinstance(data, tuple(self.types)):
+            return
+
+        if self.enabled:
+            if not self.prepared:
+                self.prepare()
+
+            self.call(data=data)
+
+    async def async_call(self, data: Data) -> None:
 
         if self.callback is not None:
             if asyncio.iscoroutinefunction(self.callback):
@@ -55,6 +76,15 @@ class Callback:
             else:
                 self.callback(data)
 
+    def call(self, data: Data) -> None:
+
+        if self.callback is not None:
+            if asyncio.iscoroutinefunction(self.callback):
+                asyncio.run(self.callback(data))
+
+            else:
+                self.callback(data)
+
     def enable(self) -> None:
 
         self.enabled = True
